==> patch-2.5.3.18_3.zip: app/views/login/ssoLogin.php <==
<?php
use Core\Language;
use Helpers\Assets;
use Helpers\Url;
use Helpers\Form; ?>
<div class="container">
    <div class="row">

    </div>
    <?php if(!isMobile()){?><br/><br/><br/><?php } ?>
    <div class="row">
        <div class="col-lg-12">
            <div class="panel panel-default no-box-shadow">
                <div class="panel-body">
                    <?php if(is_file("/var/www/portal/app/templates/default/collateral/".NEIL_IMG_NAME)){ ?>
                        <div class="col-lg-6 col-sm-12 col-xs-12 col-md-12 text-center">
                            <?php if(isMobile()){?>
                                <img style="max-width:100%;"src="<?=Url::templatePath()?>collateral/<?=NEIL_IMG_NAME?>" />
                            <?php }else { ?>
                                <img src="<?=Url::templatePath()?>collateral/<?=NEIL_IMG_NAME?>" />
                            <?php } ?>
                        </div>
                    <?php } else { ?>
                        <div class="col-lg-6 col-sm-12 col-xs-12 col-md-12 text-center">
                            <?php if(isMobile()){?>
                                <img style="max-width:100%;"src="<?=Url::templatePath()?>images/<?=NEIL_IMG_NAME?>" />
                            <?php }else { ?>
                                <img src="<?=Url::templatePath()?>images/<?=NEIL_IMG_NAME?>" />
                            <?php } ?>
                        </div>
                    <?php }?>
                    <div class="col-lg-6" <?php if(!isMobile()){ ?> style="margin-top: 95px;" <?php } ?>>
                        <div class="error" style="color: #f55753; margin-bottom: 10px;"><?=$data['newmessage']?></div>
                            <?php if($data['SSO'] != ''){?>
                                <a class="btn btn-primary" href="<?=$data['SSO']?>" style="margin-top: 20px;">Login to Portal</a>
                            <?php }else { ?>
                                <a class="btn btn-primary" href="<?=Url::basePath('login')?>" style="margin-top: 20px;">Login to Portal</a>
                            <?php } ?>
                        </div>
                    <div class="col-lg-12" style="margin-top:20px;">
                                                <div class="col-lg-10" style="margin-top:20px;">
                                                        <?php if(EULA_ENABLED == true){ ?>
                                                        <h4 style="font-size:8px;margin-left:50px;">By using all or any portion of the software, you are agreeing to be bound by all terms and conditions of Parablu’s End User License Agreement, a copy of which can be found here <a href="https://www.parablu.com/legal">https://www.parablu.com/legal</a></h4>
                                                        <?php } ?>
                              <?php
                                if(file_exists('/var/www/portal/app/templates/default/collateral/disclaimer.txt')){
                                    echo "<h4 style='font-size:8px;margin-left:50px;'>Disclaimer</h4>";
                                    foreach(file('/var/www/portal/app/templates/default/collateral/disclaimer.txt') as $line) {
                                        echo "<li style='font-size:8px;margin-left:50px;'>".$line."</li>";
                                    }
                                }else{
                                    if(file_exists('/var/www/portal/app/templates/default/images/disclaimer.txt')){
                                        echo "<h4 style='font-size:8px;margin-left:50px;'>Disclaimer</h4>";
                                        foreach(file('/var/www/portal/app/templates/default/images/disclaimer.txt') as $line) {
                                            echo "<li style='font-size:8px;margin-left:50px;'>".$line."</li>";
                                        }
                                    }
                                }
                            ?>
                  </div>
                </div>
            </div>
        </div>
    </div>
</div>

==> patch-2.5.5.0_5.zip: app/views/login/ssoLogin.php <==
<?php
use Core\Language;
use Helpers\Assets;
use Helpers\Url;
use Helpers\Form; ?>
<div class="container">
    <div class="row">
    </div>
    <?php if(!isMobile()){?><br/><br/><br/><?php } ?>
    <div class="row">
        <div class="col-lg-12">
            <div class="panel panel-default no-box-shadow">
                <div class="panel-body">
                    <?php if(is_file("/var/www/portal/app/templates/default/collateral/".NEIL_IMG_NAME)){ ?>
                        <div class="col-lg-6 col-sm-12 col-xs-12 col-md-12 text-center">
                            <?php if(isMobile()){?>
                                <img style="max-width:100%;"src="<?=Url::templatePath()?>collateral/<?=NEIL_IMG_NAME?>" alt="PARABLU"/>
                            <?php }else { ?>
                                <img src="<?=Url::templatePath()?>collateral/<?=NEIL_IMG_NAME?>" alt="PARABLU"/>
                            <?php } ?>
                        </div>
                    <?php } else { ?>
                        <div class="col-lg-6 col-sm-12 col-xs-12 col-md-12 text-center">
                            <?php if(isMobile()){?>
                                <img style="max-width:100%;"src="<?=Url::templatePath()?>images/<?=NEIL_IMG_NAME?>" alt="PARABLU"/>
                            <?php }else { ?>
                                <img src="<?=Url::templatePath()?>images/<?=NEIL_IMG_NAME?>" alt="PARABLU"/>
                            <?php } ?>
                        </div>
                    <?php }?>
                    <div class="col-lg-6" <?php if(!isMobile()){ ?> style="margin-top: 95px;" <?php } ?>>
                        <!--<div class="error" style="color: #f55753; margin-bottom: 10px;"><?=$data['newmessage']?></div>
                            <?php if($data['SSO'] != ''){?>
                                <a class="btn btn-primary" href="<?=$data['SSO']?>" style="margin-top: 20px;">Login to Portal</a>
                            <?php }else { ?>
                                <a class="btn btn-primary" href="<?=Url::basePath('login')?>" style="margin-top: 20px;">Login to Portal</a>
                            <?php } ?>
                        </div>-->
                        <div class="error" style="color: #f55753; margin-bottom: 10px;"><?=$data['newmessage']?></div>                            
                            <?php if(enableLocalLogin == false){ ?>
                                <?php if($data['SSO'] != ''){?>
                                    <a class="btn btn-primary" href="<?=$data['SSO']?>" style="margin-top: 20px;">Login to Portal</a>
                                <?php }else { ?>
                                    <a class="btn btn-primary" href="<?=Url::basePath('login')?>" style="margin-top: 20px;">Login to Portal</a>
                                <?php } ?>
                            <?php } else { ?>
                                <?php if($data['SSO'] != ''){?>
                                    <a class="btn btn-primary" href="<?=$data['SSO']?>" style="margin-top: 20px;">Internal user login</a>
                                <?php }else { ?>
                                    <a class="btn btn-primary" href="<?=Url::basePath('login')?>" style="margin-top: 20px;">Internal user login</a>
                                <?php } ?>
                                    <a class="btn btn-primary" href="<?=Url::basePath('locallogin')?>" style="margin-top: 20px;"> External user login</a>
                            <?php } ?>
                        </div>
                    <div class="col-lg-12" style="margin-top:20px;">
                                                <div class="col-lg-10" style="margin-top:20px;">
                                                        <?php if(EULA_ENABLED == true){ ?>
                                                        <h4 style="font-size:8px;margin-left:50px;">By using all or any portion of the software, you are agreeing to be bound by all terms and conditions of Parablu’s End User License Agreement, a copy of which can be found here <a href="https://www.parablu.com/legal">https://www.parablu.com/legal</a></h4>
                                                        <?php } ?>
                              <?php
                                if(file_exists('/var/www/portal/app/templates/default/collateral/disclaimer.txt')){
                                    echo "<h4 style='font-size:8px;margin-left:50px;'>Disclaimer</h4>";
                                    foreach(file('/var/www/portal/app/templates/default/collateral/disclaimer.txt') as $line) {
                                        echo "<li style='font-size:8px;margin-left:50px;'>".$line."</li>";
                                    }
                                }else{
                                    if(file_exists('/var/www/portal/app/templates/default/images/disclaimer.txt')){
                                        echo "<h4 style='font-size:8px;margin-left:50px;'>Disclaimer</h4>";
                                        foreach(file('/var/www/portal/app/templates/default/images/disclaimer.txt') as $line) {
                                            echo "<li style='font-size:8px;margin-left:50px;'>".$line."</li>";
                                        }
                                    }
                                }
                            ?>
                  </div>
                </div>
            </div>
        </div>
    </div>
</div>
